# -*- coding: utf-8 -*-
#===============================================================================
# WeatherSat Plugin by DarkVolli 2009
#
# This is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2, or (at your option) any later
# version.
#===============================================================================

from enigma import eTimer, getDesktop

from Screens.Screen import Screen
from Plugins.Plugin import PluginDescriptor

from Components.Label import Label
from Components.Pixmap import Pixmap
from Components.ActionMap import ActionMap

from Tools.LoadPixmap import LoadPixmap

from twisted.web import client


def main(session,**kwargs):
	session.open(WeatherSat)

def Plugins(**kwargs):
	return [PluginDescriptor(name="WeatherSat", description=_("shows satellite maps from the world..."), where = PluginDescriptor.WHERE_PLUGINMENU, fnc=main)]

# mainwindow...
class WeatherSat(Screen):
	def __init__(self, session, args = 0):
		maps = (
#			(_("Afghanistan"), "http://image.weather.com/looper/archive/afghan_sat_720_usen/"),
			(_("Africa"), "http://image.weather.com/looper/archive/africasat_600x405/"),
#			(_("Argentina"), "http://image.weather.com/looper/archive/sat_argent_720x486/"),
			(_("Asia"), "http://image.weather.com/looper/archive/asiasat_600x405/"),
			(_("Atlantic Ocean"), "http://image.weather.com/looper/archive/atl_oce_sat_600x405/"),
			(_("Australia"), "http://image.weather.com/looper/archive/aussiesat_600x405/"),
#			(_("Brazil"), "http://image.weather.com/looper/archive/brazil_sat_720x486/"),
#			(_("Northwest Brazil"), "http://image.weather.com/looper/archive/nwbrazilsat_720x486/"),
#			(_("Northeast Brazil"), "http://image.weather.com/looper/archive/nebrazilsat_720x486/"),
#			(_("South Brazil"), "http://image.weather.com/looper/archive/sbrazilsat_720x486/"),
#			(_("Canada"), "http://image.weather.com/looper/archive/canadasat_720x486/"),
			(_("Caribbean"), "http://image.weather.com/looper/archive/caribsat_600x405/"),
			(_("Central America"), "http://image.weather.com/looper/archive/cenamersat_600x405/"),
			(_("Central Asia"), "http://image.weather.com/looper/archive/cen_asiasat_600x405/"),
#			(_("East Asia"), "http://image.weather.com/looper/archive/east_asiasat_720x486/"),
			(_("Europe-Africa"), "http://image.weather.com/looper/archive/euro-africasat_600x405/"),
			(_("Europe"), "http://image.weather.com/looper/archive/europesat_600x405/"),
#			(_("France"), "http://image.weather.com/looper/archive/france_sat_720x486/"),
			(_("Northern Europe"), "http://image.weather.com/looper/archive/germany_sat_600x405/"),
			(_("Germany"), "http://image.weather.com/looper/archive/germany_sat_600_nl/"),
			(_("Gulf of Mexico"), "http://image.weather.com/looper/archive/gomex_sat_600x405/"),
			(_("India"), "http://image.weather.com/looper/archive/india_sat_600x405/"),
#			(_("Indian Ocean"), "http://image.weather.com/looper/archive/indian_oce_sat_720x486/"),
			(_("Italy"), "http://image.weather.com/looper/archive/italy_sat_600x405/"),
			(_("Japan"), "http://image.weather.com/looper/archive/japan_sat_600x405/"),
			(_("Central Mexico"), "http://image.weather.com/looper/archive/mexcensat_600x405/"),
			(_("Mexico"), "http://image.weather.com/looper/archive/mexsat_600x405/"),
			(_("Middle East"), "http://image.weather.com/looper/archive/mideastsat_600x405/"),
#			(_("New Zealand"), "http://image.weather.com/looper/archive/new_zealsat_720x486/"),
#			(_("Pacific Global"), "http://image.weather.com/looper/archive/pacglobsat_720x486/"),
			(_("Pacific Ocean"), "http://image.weather.com/looper/archive/pac_oce_sat_600x405/"),
			(_("Russia"), "http://image.weather.com/looper/archive/russia_sat_600x405/"),
			(_("Scandinavia"), "http://image.weather.com/looper/archive/scand_sat_600x405/"),
			(_("South America"), "http://image.weather.com/looper/archive/sasat_600x405/"),
			(_("Tropical Atlantic"), "http://image.weather.com/looper/archive/tropsat_600x405/"),
			(_("United Kingdom"), "http://image.weather.com/looper/archive/uksat_600x405/"),
#			(_("Venezuela"), "http://image.weather.com/looper/archive/colomven_sat_720x486/"),
			(_("Western Pacific Ocean"), "http://image.weather.com/looper/archive/wpacglobsat_600x405/"),
			(_("Hemisphere-Western"), "http://image.weather.com/looper/archive/goesdisk_600x405/")
		)

		# get framebuffer resolution...
		desk = getDesktop(0)
		w = int(desk.size().width())
		h = int(desk.size().height())

		size_w = 600
		size_h = 405
		self.maxslices = 5

		# display frame in center...
		x = (w - size_w) / 2
		y = (h - size_h) / 2

		# set skin...
		self.skin = "<screen position=\"0,0\" size=\"" + str(w) + "," + str(h) + "\" flags=\"wfNoBorder\">" +\
		"<eLabel position=\"0,0\" size=\"" + str(w) + "," + str(h) + "\" zPosition=\"0\" backgroundColor=\"#000000\" />" +\
		"<widget name=\"msg1\" position=\"0," + str(y-40) + "\" size=\"" + str(w) + ",30\" zPosition=\"1\" backgroundColor=\"#000000\" halign=\"center\" font=\"Regular;20\" />" +\
		"<widget name=\"msg2\" position=\"0," + str(h/2) + "\" size=\"" + str(w) + ",30\" zPosition=\"1\" backgroundColor=\"#000000\" halign=\"center\" font=\"Regular;20\" />" +\
		"<widget name=\"frame\" position=\"" + str(x) + "," + str(y) + "\" size=\"" + str(size_w) + "," + str(size_h) + "\" zPosition=\"2\" transparent=\"1\" alphatest=\"off\" />" +\
		"<widget name=\"map\" position=\"0," + str(y+size_h+10) + "\" size=\"" + str(w) + ",30\" zPosition=\"1\" backgroundColor=\"#000000\" halign=\"center\" font=\"Regular;20\" />" +\
		"</screen>"

		Screen.__init__(self, session)

		# Load maps...
		self.maplist = []
		for m in maps:
			self.maplist.append((m[0], m[1]))

		self["msg1"] = Label(_("Press ok for load new map!"))
		self["msg1"].hide()
		self["msg2"] = Label()
		self.maxMaps = len(self.maplist) - 1
		self.actualMap = 8
		self.oldMap = 8
		self["map"] = Label(self.maplist[self.actualMap][0])
		self.url = self.maplist[self.actualMap][1]

		self["actions"] = ActionMap(["OkCancelActions", "WizardActions"],
		{
			"cancel": self.exit,
			"ok": self.key_ok,
			"left": self.key_left,
			"right": self.key_right
		}, -1)

		self["frame"] = Pixmap()

		self.onLayoutFinish.append(self.startup)

	def startup(self):
		self.Slice = 0
		self.timer = eTimer()
		self.timer.callback.append(self.timerEvent)
		self.startDownload()

	def timerEvent(self):
		self.Slice=(self.Slice+1) % self.maxslices
		self["frame"].instance.setPixmap(self.pics[self.Slice])
		self["frame"].show()

	def startDownload(self):
		self["msg2"].setText(_("Please wait, downloading data..."))
		self.timer.stop()
		self.download = True
		self.picNum = 0
		self.downloadPic(self.picNum)

	def downloadPic(self, x):
		print "[WeatherSat] download", self.url+str(x+1)+"L.jpg"
		client.downloadPage(self.url+str(x+1)+"L.jpg", "/tmp/"+str(x)+"L.jpg").addCallback(self.dlFinished).addErrback(self.dlFailed)

	def dlFinished(self, retval = False):
		if self.picNum < self.maxslices - 1:
			self.picNum += 1
			self.downloadPic(self.picNum)
		else:
			print "[WeatherSat] download finished"
			self.pics = []
			for x in range(self.maxslices):
				self.pics.append(LoadPixmap("/tmp/" + str(x) + "L.jpg"))
			if self.download:
				self.timer.start(400)
				self.download = False

	def dlFailed(self, retval):
		print "[WeatherSat] download error: " + retval.getErrorMessage()
		self["msg2"].setText(_("download error: ") + retval.getErrorMessage())

	def key_ok(self):
		self.url = self.maplist[self.actualMap][1]
		self["msg1"].hide()
		self["frame"].hide()
		self.oldMap = self.actualMap
		self.startDownload()

	def key_left(self):
		self.actualMap -= 1
		if self.actualMap < 0:
			self.actualMap = self.maxMaps
		if self.oldMap != self.actualMap:
			self["msg1"].show()
		else:
			self["msg1"].hide()
		self["map"].setText(self.maplist[self.actualMap][0])

	def key_right(self):
		self.actualMap += 1
		if self.actualMap > self.maxMaps:
			self.actualMap = 0
		if self.oldMap != self.actualMap:
			self["msg1"].show()
		else:
			self["msg1"].hide()
		self["map"].setText(self.maplist[self.actualMap][0])

	def exit(self):
		self.timer.stop()
		self.timer.callback.remove(self.timerEvent)
		self.close()
